using System;
using Server;
using Server.Mobiles;
using Server.Network;
using Server.Regions;
using Server.Items;
using Server.Targeting;

namespace Server.Items
{
    public class ContributorSash : BodySash
    {
        #region ItemDeleteTimer [01-04]

        private static readonly TimeSpan m_Delay = TimeSpan.FromDays(31);
        private InternalTimer m_ItemDeleteTimer;

        [CommandProperty(AccessLevel.GameMaster, true)]
        public TimeSpan Remaining
        {
            get { if (m_ItemDeleteTimer != null) return m_ItemDeleteTimer.GetDelay().Subtract(DateTime.Now); else return TimeSpan.Zero; }
        }

        #endregion Edited By: A.A.R

        public override int BasePhysicalResistance { get { return 20; } }

        [Constructable]
        public ContributorSash()
        {
            Name = "Contributor Sash";
            Hue = 90;

            switch (Utility.Random(3))
            {
                case 0: //Pure Mage
                    SkillBonuses.SetValues(0, SkillName.EvalInt, 10);
                    SkillBonuses.SetValues(1, SkillName.MagicResist, 10);
                    SkillBonuses.SetValues(2, SkillName.Magery, 10);
                    SkillBonuses.SetValues(3, SkillName.Inscribe, 10);
                    SkillBonuses.SetValues(4, SkillName.Meditation, 10);
                    break;
                case 1: //Nox Mage
                    SkillBonuses.SetValues(0, SkillName.EvalInt, 10);
                    SkillBonuses.SetValues(1, SkillName.MagicResist, 10);
                    SkillBonuses.SetValues(2, SkillName.Magery, 10);
                    SkillBonuses.SetValues(3, SkillName.Poisoning, 10);
                    SkillBonuses.SetValues(4, SkillName.Meditation, 10);
                    break;
                case 2: //Warrior
                    SkillBonuses.SetValues(0, SkillName.Swords, 10);
                    SkillBonuses.SetValues(1, SkillName.Healing, 10);
                    SkillBonuses.SetValues(2, SkillName.Tactics, 10);
                    SkillBonuses.SetValues(3, SkillName.Anatomy, 10);
                    SkillBonuses.SetValues(4, SkillName.Lumberjacking, 10);
                    break;
            }

            Attributes.SpellChanneling = 1;
            Attributes.RegenMana = 3;
            Attributes.BonusMana = 8;
            Attributes.LowerRegCost = 100;

            Attributes.NightSight = 1;

            LootType = LootType.Blessed;
        }

        #region ItemDeleteTimer [02-04]

        public override void AddNameProperty(ObjectPropertyList list)
        {
            base.AddNameProperty(list);

            if (m_ItemDeleteTimer != null)
            {
                string lisths;
                TimeSpan timetouse = m_ItemDeleteTimer.GetDelay().Subtract(DateTime.Now);

                if (timetouse.Days > 0)
                {
                    int day = timetouse.Days;
                    lisths = String.Format("{0} days", day.ToString());
                }
                else if (timetouse.Minutes > 0)
                {
                    int min = timetouse.Minutes;
                    lisths = String.Format("{0} minutes", min.ToString());
                }
                else if (timetouse.Seconds > 0)
                {
                    int sec = timetouse.Seconds;
                    lisths = String.Format("{0} seconds", sec.ToString());
                }
                else
                {
                    lisths = ("<BASEFONT COLOR=#C0C0C0> | <BASEFONT COLOR=#C0C0C0>");
                }

                list.Add("<BASEFONT COLOR=#C0C0C0>Time Remaining: {0}<BASEFONT COLOR=#C0C0C0>", lisths);
                Timer.DelayCall(TimeSpan.FromSeconds(1.0), new TimerCallback(InvalidateProperties));
            }
        }

        public override bool OnEquip(Mobile from)
        {
            if (base.OnEquip(from))
            {
                if (m_ItemDeleteTimer == null)
                {
                    //Insert Item Name Below:
                    m_ItemDeleteTimer = new ContributorSash.InternalTimer(this, DateTime.Now + m_Delay);
                    m_ItemDeleteTimer.Start();
                    Timer.DelayCall(TimeSpan.FromSeconds(1.0), new TimerCallback(InvalidateProperties));
                }
            }
            return true;
        }

        protected class InternalTimer : Timer
        {
            private Item m_Item;
            public InternalTimer(Item item, DateTime end): base(end.Subtract(DateTime.Now))
            {
                m_Item = item;
                Priority = TimerPriority.FiveSeconds;
            }

            public DateTime GetDelay()
            {
                return this.Next;
            }

            protected override void OnTick()
            {
                if (m_Item != null && !m_Item.Deleted)
                {
                    if (m_Item.Parent is Mobile)
                        ((Mobile)m_Item.Parent).SendMessage("We're Sorry But Your Item's Time Has Expired!");
                    m_Item.Delete();
                }

                Stop();
            }
        }

        #endregion Edited By: A.A.R

        public ContributorSash(Serial serial): base(serial)
        {
        }

        public override void Serialize(GenericWriter writer)
        {
            base.Serialize(writer);
            writer.Write((int)1); // version

            #region ItemDeleteTimer [03-04]

            writer.Write((bool)(m_ItemDeleteTimer != null));
            if (m_ItemDeleteTimer != null)
            {
                writer.WriteDeltaTime(m_ItemDeleteTimer.GetDelay());
            }

            #endregion Edited By: A.A.R
        }

        public override void Deserialize(GenericReader reader)
        {
            base.Deserialize(reader);
            int version = reader.ReadInt();

            #region ItemDeleteTimer [04-04]

            switch (version)
            {
                case 0:
                    {
                        reader.ReadDateTime();
                        break;
                    }
                case 1:
                    {
                        if (reader.ReadBool())
                        {
                            DateTime end = reader.ReadDeltaTime();
                            //Insert Item Name Below:
                            m_ItemDeleteTimer = new ContributorSash.InternalTimer(this, end);
                            m_ItemDeleteTimer.Start();
                        }
                        break;
                    }
            }

            #endregion Edited By: A.A.R
        }
    }
}

      